function varargout = Power_Spectra_Help(varargin)
% POWER_SPECTRA_HELP M-file for Power_Spectra_Help.fig
%      POWER_SPECTRA_HELP, by itself, creates a new POWER_SPECTRA_HELP or raises the existing
%      singleton*.
%
%      H = POWER_SPECTRA_HELP returns the handle to a new POWER_SPECTRA_HELP or the handle to
%      the existing singleton*.
%
%      POWER_SPECTRA_HELP('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in POWER_SPECTRA_HELP.M with the given input arguments.
%
%      POWER_SPECTRA_HELP('Property','Value',...) creates a new POWER_SPECTRA_HELP or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before Power_Spectra_Help_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to Power_Spectra_Help_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help Power_Spectra_Help

% Last Modified by GUIDE v2.5 21-May-2006 22:27:47

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @Power_Spectra_Help_OpeningFcn, ...
                   'gui_OutputFcn',  @Power_Spectra_Help_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before Power_Spectra_Help is made visible.
function Power_Spectra_Help_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to Power_Spectra_Help (see VARARGIN)

% Choose default command line output for Power_Spectra_Help
handles.output = hObject;


% Update handles structure
guidata(hObject, handles);

% UIWAIT makes Power_Spectra_Help wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = Power_Spectra_Help_OutputFcn(hObject, eventdata, handles) 

varargout{1} = handles.output;


% --- Executes on selection change in listbox1.
function listbox1_Callback(hObject, eventdata, handles)

% --- Executes during object creation, after setting all properties.
function listbox1_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end




% --- Executes on button press in Close.
function Close_Callback(hObject, eventdata, handles)
delete(gcf)


